@@ -1,21 +1,16 @@
-import os
-import csv
-import sys
-import math
-import json
 import argparse
-from collections import OrderedDict
 
 from simple_csv_reader.helpers import *
+from simple_csv_reader.csv_reader import CSVReader
 
 parser = argparse.ArgumentParser(description='CSV reader')
-parser.add_argument('-f', '--file', dest='file_path', help='the path of the CSV file')
+parser.add_argument('-f', '--file', dest='file_path', help='the path of the CSV file', required=True)
 parser.add_argument('-m', '--missing-header', default=False, action='store_true', dest='missing_header', help='flag to manually input headers')
 parser.add_argument('-s', '--separator', default=';', dest='separator', help='the separator used in the CSV file')
 
 cli_helper = CliHelper()
 
-if __name__ == "__main__":
+def main():
     args = parser.parse_args(sys.argv[1:])
     cli_helper.screen_clear()
     csv_reader = CSVReader(args.file_path, args.missing_header, args.separator, lambda x: cli_helper.print_percentage(x, "Loading File: "))
@@ -23,9 +18,10 @@ if __name__ == "__main__":
     while True:
         cli_helper.screen_clear()
         choice = cli_helper.print_menu("MAIN", {
-            "1": "READ CSV FILE",
+            "1": "READ CSV FILE ({} ELEMENTS)".format(len(csv_reader.data)),
             "2": "SELECT/UNSELECT COLUMNS",
             "3": "ADD FILTERS",
+            "4": "CLEAR FILTERS",
             "0": "EXIT"
         })
         if choice == "1":
@@ -41,7 +37,7 @@ if __name__ == "__main__":
                     if page > 0:
                         page -= 1
                 elif char == 's':
-                    if page < math.ceil(len(csv_reader.data) / 20):
+                    if page < csv_reader.total_pages - 1:
                         page += 1
                 elif char == 'q':
                     break
@@ -51,27 +47,44 @@ if __name__ == "__main__":
                 cli_helper.screen_clear()
                 for index, column_name in enumerate(csv_reader.columns):
                     verb = "HIDE" if csv_reader.column_structs[column_name]['visible'] else "SHOW"
-                    menu[index] = "{} {} COLUMN".format(verb, column_name)
+                    menu[index] = "{} COLUMN `{}`".format(verb, column_name)
                 menu["back"] = ""
                 selection = cli_helper.print_menu("MAIN -> SELECT/UNSELECT COLUMNS", menu)
                 if selection != "back":
-                    csv_reader.toggle_column(csv_reader.columns[int(selection)])
+                    column_name = csv_reader.columns[int(selection)]
+                    csv_reader.toggle_column(column_name)
                 else:
                     break
         if choice == "3":
             while True:
                 menu = {}
                 cli_helper.screen_clear()
-                for column_name, struct in csv_reader.column_structs.items():
-                    menu[column_name] = struct["filters"]
+                for index, column_name in enumerate(csv_reader.columns):
+                    menu[index] = "COLUMN `{}` ACTIVE FILTERS {}".format(column_name, csv_reader.column_structs[column_name]['filters'])
                 menu["back"] = ""
-                column_name = cli_helper.print_menu("MAIN -> ADD FILTERS", menu)
-                if column_name in csv_reader.columns:
+                selection = cli_helper.print_menu("MAIN -> ADD FILTERS", menu)
+                if selection != "back":
                     afilter = input("Type keyword: ")
+                    column_name = csv_reader.columns[int(selection)]
                     csv_reader.add_filter(column_name, afilter)
-                if column_name == "back":
+                else:
+                    break
+        if choice == "4":
+            while True:
+                menu = {}
+                cli_helper.screen_clear()
+                for index, column_name in enumerate(csv_reader.columns):
+                    menu[index] = "COLUMN `{}` ACTIVE FILTERS {}".format(column_name, csv_reader.column_structs[column_name]['filters'])
+                menu["back"] = ""
+                selection = cli_helper.print_menu("MAIN -> CLEAR FILTERS", menu)
+                if selection != "back":
+                    csv_reader.clear_filter(csv_reader.columns[int(selection)])
+                else:
                     break
 
         if choice == "0":
             cli_helper.screen_clear()
             break
+
+if __name__ == "__main__":
+    main()
