@@ -1,3 +1,11 @@
+import csv
+import sys
+import math
+import json
+import os
+from collections import OrderedDict
+
+
 class CSVReader:
 
     column_structs = OrderedDict()
@@ -32,11 +40,28 @@ class CSVReader:
                 for column_name in next(csv_reader):
                     self.__init_column(column_name)
 
-            # parse it
+            # count elements to calculate loading percentage
+            total_elements = sum(1 for row in csv_reader)
+            csv_file.seek(0)
+
+            # finally fetching
             for line_count, row in enumerate(csv_reader):
                 self.raw_data += [{column: row[index] for index, column in enumerate(self.columns)}]
-                percentage = line_count / 5000000 * 100
+                percentage = line_count / total_elements * 100
                 callback(percentage)
+            callback(100)
+
+    @property
+    def columns(self):
+        return list(self.column_structs.keys())
+
+    @property
+    def data(self):
+        return list(filter(lambda e: all([all([f in v for f in self.column_structs[k]['filters']]) for k, v in e.items()]), self.raw_data))
+
+    @property
+    def total_pages(self):
+        return math.ceil(len(self.data) / 20)
 
     def toggle_column(self, column_name):
         self.column_structs[column_name]['visible'] = not self.column_structs[column_name]['visible']
@@ -48,19 +73,11 @@ class CSVReader:
     def clear_filter(self, column_name):
         self.column_structs[column_name]['filters'] = []
 
+    def get_data(self, page, page_size):
+        return self.data[page * page_size:(page + 1) * page_size]
+
     def __init_column(self, column_name):
         self.column_structs[column_name] = {
             "filters": [],
             "visible": True
         }
-
-    @property
-    def columns(self):
-        return list(self.column_structs.keys())
-
-    @property
-    def data(self):
-        return list(filter(lambda e: all([all([f in v for f in self.column_structs[k]['filters']]) for k, v in e.items()]), self.raw_data))
-
-    def get_data(self, page, page_size):
-        return self.data[page * page_size:(page + 1) * page_size]
